# Certgrinder client: certgrinder

[![Checked with mypy](../docs/badges/mypy_badge.svg)](http://mypy-lang.org/)
[![Checked with flake8](../docs/badges/flake8-OK-green.svg)](http://flake8.pycqa.org/en/latest/)
[![Codestyle black](../docs/badges/black.svg)](https://github.com/psf/black/)
[![PyPI](https://img.shields.io/pypi/v/certgrinder.svg)](https://pypi.org/project/certgrinder/)
[![PyPI downloads](https://img.shields.io/pypi/dm/certgrinder.svg)](https://pypi.org/project/certgrinder/)

This is the client part of the [Certgrinder project](https://certgrinder.readthedocs.io/en/latest/introduction.html). The package is called ``certgrinder``. It can be installed [from pypi](https://pypi.org/project/certgrinder/).

It is meant to be used with the [certgrinderd](https://pypi.org/project/certgrinderd/) server package.

Documentation can be found at ReadTheDocs: https://certgrinder.readthedocs.io/en/latest/certgrinder.html
